@@ -14,6 +14,8 @@ import re
 
 import six
 
+from distutils import util
+
 from ocldev import oclconstants
 
 
@@ -65,7 +67,7 @@ class OclCsvToJsonConverter(object):
     REPLACE_CHAR = '-'
 
     def __init__(self, csv_filename='', input_list=None,
-                 csv_resource_definitions=None, verbose=False):
+                 csv_resource_definitions=None, verbose=False, allow_special_characters=False):
         """
         Initialize this object
         :param csv_filename: <string> Filename to load CSV data from; use "input_list"
@@ -74,7 +76,9 @@ class OclCsvToJsonConverter(object):
         :param csv_resource_definitions: <dict> Properly formatted dictionary defining
             how to convert CSV to OCL-JSON
         :param verbose: <int> 0=off, 1=some debug info, 2=all debug info
+        :param allow_special_characters: <bool> concept id special characters will not be replaced by `-`
         """
+        self.allow_special_characters = allow_special_characters
         self.csv_filename = csv_filename
         self.input_list = input_list
         if csv_filename:
@@ -435,13 +439,22 @@ class OclCsvToJsonConverter(object):
             auto_attributes_def[self.DEF_KEY_AUTO_INDEX_REGEX],
             re.escape(auto_attributes_def[self.DEF_KEY_AUTO_INDEX_POSTFIX]))
 
+        data_types = ['bool', 'str', 'int', 'float', 'list', 'json']
+
         # Process CSV columns
         for column_name in csv_row:
+            data_type = 'str'
+            if column_name.count(':') == 2:
+                suffix_part = column_name.split(':')[2].strip()
+                if suffix_part in data_types:
+                    data_type = suffix_part
             if column_name[:len(standard_needle)] == standard_needle:
                 # Check if standard attr (e.g. attr:my-custom-attr)
                 if not omit_if_empty_value or (omit_if_empty_value and csv_row[column_name]):
                     key_name = column_name[len(standard_needle):]
-                    extra_attributes[key_name] = csv_row[column_name]
+                    if key_name.endswith(":" + data_type):
+                        key_name = key_name.replace(":" + data_type, "")
+                    extra_attributes[key_name] = self.do_datatype_conversion(csv_row[column_name], data_type)
             else:
                 key_regex_match = re.search(key_needle, column_name)
                 value_regex_match = re.search(value_needle, column_name)
@@ -708,11 +721,18 @@ class OclCsvToJsonConverter(object):
         desired datatype (e.g. datatype="bool", "int", "float").
         """
         if datatype == 'bool':
-            return bool(value)
+            return bool(util.strtobool(str(value)))
         elif datatype == 'int':
             return int(value)
         elif datatype == 'float':
             return float(value)
+        elif datatype == 'list':
+            return [v.strip() for v in value.strip('][').split(',')]
+        elif datatype == 'json':
+            try:
+                return json.loads(value)
+            except:
+                return value
         return value
 
     def process_auto_concept_reference(self, csv_row, field_def):
@@ -740,6 +760,9 @@ class OclCsvToJsonConverter(object):
         Format a string according to the OCL ID rules: Everything in INVALID_CHARS goes,
         except that underscores are allowed for the concept_id
         """
+        if self.allow_special_characters:
+            return unformatted_id
+
         formatted_id = list(unformatted_id)
         if allow_underscore:
             # Remove underscore from the invalid characters - Concept IDs are okay with underscores
@@ -877,11 +900,14 @@ class OclStandardCsvToJsonConverter(OclCsvToJsonConverter):
             '__trigger_value': oclconstants.OclConstants.RESOURCE_TYPE_CONCEPT,
             'skip_if_empty_column': 'id',
             OclCsvToJsonConverter.DEF_CORE_FIELDS: [
-                {'resource_field': 'retired', 'column': 'retired', 'required': False},
+                {'resource_field': 'retired', 'column': 'retired', 'required': False, 'datatype': 'bool'},
                 {'resource_field': 'external_id', 'column': 'external_id', 'required': False},
                 {'resource_field': 'concept_class', 'column': 'concept_class'},
+                {'resource_field': 'parent_concept_urls', 'column': 'parent_concept_urls',
+                 'default': None, 'datatype': 'list'},
                 {'resource_field': 'datatype', 'column': 'datatype', 'default': 'None'},
                 {'resource_field': 'owner', 'column': 'owner_id'},
+                {'resource_field': 'update_comment', 'column': 'update_comment'},
                 {'resource_field': 'owner_type', 'column': 'owner_type',
                  'default': oclconstants.OclConstants.RESOURCE_TYPE_ORGANIZATION},
                 {'resource_field': 'source', 'column': 'source'},
@@ -969,6 +995,7 @@ class OclStandardCsvToJsonConverter(OclCsvToJsonConverter):
                      'default': oclconstants.OclConstants.MAPPING_TARGET_INTERNAL},
                     {'resource_field': 'map_type', 'column_prefix': 'map_type',
                      'default': 'Same As'},
+                    {'resource_field': 'update_comment', 'column': 'update_comment'},
                     {'resource_field': 'external_id', 'column_prefix': 'map_external_id',
                      'required': False},
                     {'resource_field': 'from_concept_url', 'column_prefix': 'map_from_concept_url',
@@ -1023,6 +1050,7 @@ class OclStandardCsvToJsonConverter(OclCsvToJsonConverter):
                      'default': oclconstants.OclConstants.MAPPING_TARGET_EXTERNAL},
                     {'resource_field': 'map_type', 'column_prefix': 'extmap_type',
                      'default': 'Same As'},
+                    {'resource_field': 'update_comment', 'column': 'update_comment'},
                     {'resource_field': 'external_id', 'column_prefix': 'extmap_external_id',
                      'required': False},
                     {'resource_field': 'from_concept_url', 'required': False,
@@ -1109,6 +1137,7 @@ class OclStandardCsvToJsonConverter(OclCsvToJsonConverter):
                 {'resource_field': 'map_target', 'column': 'map_target',
                  'default': oclconstants.OclConstants.MAPPING_TARGET_INTERNAL},
                 {'resource_field': 'map_type', 'column': 'map_type', 'default': 'Same As'},
+                {'resource_field': 'update_comment', 'column': 'update_comment'},
                 {'resource_field': 'external_id', 'column': 'external_id',
                  'required': False},
                 {'resource_field': 'from_concept_url', 'required': False,
@@ -1154,6 +1183,7 @@ class OclStandardCsvToJsonConverter(OclCsvToJsonConverter):
                 {'resource_field': 'map_target', 'column': 'map_target',
                  'default': oclconstants.OclConstants.MAPPING_TARGET_EXTERNAL},
                 {'resource_field': 'map_type', 'column': 'map_type', 'default': 'Same As'},
+                {'resource_field': 'update_comment', 'column': 'update_comment'},
                 {'resource_field': 'external_id', 'column': 'external_id',
                  'required': False},
                 {'resource_field': 'from_concept_url', 'required': False,
@@ -1237,8 +1267,12 @@ class OclStandardCsvToJsonConverter(OclCsvToJsonConverter):
         },
     ]
 
-    def __init__(self, csv_filename='', input_list=None, verbose=False):
+    def __init__(self, csv_filename='', input_list=None, verbose=False, allow_special_characters=False):
         """ Initialize the object with the standard CSV resource definition """
         OclCsvToJsonConverter.__init__(
-            self, csv_filename=csv_filename, input_list=input_list,
-            csv_resource_definitions=self.default_csv_resource_definitions, verbose=verbose)
+            self, csv_filename=csv_filename,
+            input_list=input_list,
+            csv_resource_definitions=self.default_csv_resource_definitions,
+            verbose=verbose,
+            allow_special_characters=allow_special_characters
+        )
