@@ -1,3 +1,5 @@
+import six
+
 import ocldev.oclresourcelist
 
 
@@ -5,7 +7,7 @@ def test_get_resource():
     resources = ocldev.oclresourcelist.OclResourceList()
     resource = {'resource_type': 'Concept', 'id': 'A', 'name': 'Bob', 'owner_id': 'PEPFAR', 'source': 'PLM'}
     resources.append(resource)
-    print resources[0]
+    six.print_(resources[0])
     assert resource == resources[0]
 
 
@@ -18,7 +20,7 @@ def test_resource_iterator():
     count = 0
     for resource in resources:
         count += 1
-        print resource
+        six.print_(resource)
     assert count == len(resources)
 
 
@@ -38,7 +40,7 @@ def test_csv_to_json_conversion():
     }
     csv_resources.append(csv_resource_a)
     json_resources = csv_resources.convert_to_ocl_formatted_json()
-    print json_resources.to_json()
+    six.print_(json_resources.to_json())
     expected_json_output = [
         {
             'type': 'Concept',
@@ -116,13 +118,13 @@ def test_display_resource_list_as_csv():
 
 
 def test_load_from_file():
-    filename = 'sample.csv'
+    filename = './tests/sample.csv'
     resource_list = ocldev.oclresourcelist.OclCsvResourceList.load_from_file(filename)
     assert len(resource_list) == 66
 
 
 def test_summarize():
-    filename = 'sample.csv'
+    filename = './tests/sample.csv'
     csv_resources = ocldev.oclresourcelist.OclCsvResourceList.load_from_file(filename)
     json_resources = csv_resources.convert_to_ocl_formatted_json()
     csv_resource_type_summary = csv_resources.summarize(core_attr_key='resource_type')
